@@ -1,5 +1,5 @@
 # ChannelAttribution: Markov model for online multi-channel attribution
-# Copyright (C) 2015 - 2021  Davide Altomare and David Loris <http://www.channelattribution.net>
+# Copyright (C) 2015 - 2022  Davide Altomare and David Loris <https://channelattribution.io>
 
 # ChannelAttribution is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 .onAttach = function(libname, pkgname) {
 
  packageStartupMessage(paste0("ChannelAttribution ",.v))
- packageStartupMessage("Looking for attribution at path level? Try ChannelAttributionPro! Visit www.channelattribution.net for more information.")
+ packageStartupMessage("Looking for attribution at path level? Try ChannelAttributionPro! Visit https://channelattribution.io for more information.")
 
 }
 
